@@ -1,8 +1,8 @@
 /*************************************************************************
 ** CMap.cpp                                                             **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2021 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,21 +18,18 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <config.h>
 #include <algorithm>
 #include <sstream>
-#include <set>
-#include <vector>
-#include "CMap.h"
-#include "CMapManager.h"
-#include "FileFinder.h"
-#include "InputReader.h"
+#include "CMap.hpp"
+#include "CMapManager.hpp"
+#include "FileFinder.hpp"
+#include "Unicode.hpp"
 
 using namespace std;
 
 
 const char* CMap::path () const {
-	return FileFinder::lookup(name(), "cmap", false);
+	return FileFinder::instance().lookup(name(), "cmap", false);
 }
 
 
@@ -42,6 +39,22 @@ const FontEncoding* CMap::findCompatibleBaseFontMap (const PhysicalFont *font, C
 
 //////////////////////////////////////////////////////////////////////
 
+void SegmentedCMap::addCIDRange (uint32_t first, uint32_t last, uint32_t cid) {
+	if (uint32_t cp = Unicode::fromSurrogate(first))  // is 'first' a surrogate?
+		first = cp;
+	if (uint32_t cp = Unicode::fromSurrogate(last))   // is 'last' a surrogate?
+		last = cp;
+	_cidranges.addRange(first, last, cid);
+}
+
+
+void SegmentedCMap::addBFRange (uint32_t first, uint32_t last, uint32_t chrcode) {
+	if (uint32_t cp = Unicode::fromSurrogate(chrcode))  // is 'chrcode' a surrogate?
+		chrcode = cp;
+	_bfranges.addRange(first, last, chrcode);
+}
+
+
 /** Returns the RO (Registry-Ordering) string of the CMap. */
 string SegmentedCMap::getROString() const {
 	if (_registry.empty() || _ordering.empty())
@@ -50,8 +63,19 @@ string SegmentedCMap::getROString() const {
 }
 
 
+bool SegmentedCMap::mapsToUnicode () const {
+	vector<string> encstrings = {"UTF8", "UTF16", "UCS2", "UCS4", "UCS32"};
+	for (const string &encstr : encstrings) {
+		size_t pos = _filename.find(encstr);
+		if (pos != string::npos && (pos == 0 || _filename[pos-1] == '-'))
+			return true;
+	}
+	return false;
+}
+
+
 /** Returns the CID for a given character code. */
-UInt32 SegmentedCMap::cid (UInt32 c) const {
+uint32_t SegmentedCMap::cid (uint32_t c) const {
 	if (_cidranges.valueExists(c))
 		return _cidranges.valueAt(c);
 	if (_basemap)
@@ -61,7 +85,7 @@ UInt32 SegmentedCMap::cid (UInt32 c) const {
 
 
 /** Returns the character code of a base font for a given CID. */
-UInt32 SegmentedCMap::bfcode (UInt32 cid) const {
+uint32_t SegmentedCMap::bfcode (uint32_t cid) const {
 	if (_bfranges.valueExists(cid))
 		return _bfranges.valueAt(cid);
 	if (_basemap)
