@@ -1,8 +1,8 @@
 /*************************************************************************
 ** EPSFile.cpp                                                          **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2021 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,20 +18,20 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <config.h>
+#include <array>
 #include <cstring>
 #include <istream>
 #include <limits>
-#include "EPSFile.h"
-#include "InputBuffer.h"
-#include "InputReader.h"
+#include "EPSFile.hpp"
+#include "InputBuffer.hpp"
+#include "InputReader.hpp"
 
 using namespace std;
 
 
 /** Reads a little-endian 32-bit integer from the given input stream. */
-static UInt32 getUInt32 (istream &is) {
-	UInt32 value=0;
+static uint32_t getUInt32 (istream &is) {
+	uint32_t value=0;
 	char buf[4];
 	is.read(buf, 4);
 	for (int i=0; i < 4; i++)
@@ -57,21 +57,20 @@ static size_t getline (istream &is, char *line, size_t n) {
 }
 
 
-EPSFile::EPSFile (const std::string& fname) : _ifs(fname.c_str(), ios::binary), _headerValid(false), _offset(0), _pslength(0)
-{
+EPSFile::EPSFile (const string &fname) : _ifs(fname, ios::binary) {
 	if (_ifs) {
-		if (getUInt32(_ifs) != 0xC6D3D0C5)     // no binary header present?
-			_ifs.seekg(0, ios_base::beg);       // go back to the first byte
+		if (getUInt32(_ifs) != 0xC6D3D0C5)  // no binary header present?
+			_ifs.seekg(0);                   // go back to the first byte
 		else {
-			_offset = getUInt32(_ifs);          // stream offset where PS part of the file begins
-			_pslength = getUInt32(_ifs);        // length of PS section in bytes
-			_ifs.seekg(_offset, ios_base::beg); // continue reading at the beginning of the PS section
+			_offset = getUInt32(_ifs);       // stream offset where PS part of the file begins
+			_pslength = getUInt32(_ifs);     // length of PS section in bytes
+			_ifs.seekg(_offset);             // continue reading at the beginning of the PS section
 		}
 		string str;
-		str += _ifs.get();
-		str += _ifs.get();
+		str += char(_ifs.get());
+		str += char(_ifs.get());
 		_headerValid = (str == "%!");
-		_ifs.seekg(0, ios_base::beg);
+		_ifs.seekg(0);
 	}
 }
 
@@ -80,15 +79,15 @@ EPSFile::EPSFile (const std::string& fname) : _ifs(fname.c_str(), ios::binary),
  *  to the beginning of the ASCII (PostScript) part of the file. */
 istream& EPSFile::istream () const {
 	_ifs.clear();
-	_ifs.seekg(_offset, ios_base::beg);
+	_ifs.seekg(_offset);
 	return _ifs;
 }
 
 
-/** Extracts the bounding box information from the DSC header/footer (if present)
- *  @param[out] the extracted bounding box
- *  @return true if %%BoundingBox data could be read successfully */
-bool EPSFile::bbox (BoundingBox &box) const {
+/** Extracts the bounding box information from the DSC header/footer (if present).
+ *  @return the extracted bounding box */
+BoundingBox EPSFile::bbox () const {
+	BoundingBox box;
 	std::istream &is = EPSFile::istream();
 	if (is) {
 		char buf[64];
@@ -100,16 +99,16 @@ bool EPSFile::bbox (BoundingBox &box) const {
 				ir.skip(14);
 				ir.skipSpace();
 				if (!ir.check("(atend)", true)) {
-					int val[4];
-					for (int i=0; i < 4; i++) {
+					array<int, 4> values;
+					for (int &v : values) {
 						ir.skipSpace();
-						ir.parseInt(val[i]);
+						ir.parseInt(v);
 					}
-					box = BoundingBox(val[0], val[1], val[2], val[3]);
-					return true;
+					box = BoundingBox(values[0], values[1], values[2], values[3]);
+					break;
 				}
 			}
 		}
 	}
-	return false;
+	return box;
 }
